==> gpe-expenses_0.1.4.orig.tar.gz: gpe-expenses-0.1.4/doc/doxygen_main_page.c <==
/* Copyright  2005  Neil Williams <linux@codehelp.co.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
/** @mainpage gpe-expenses

QOF is Query Object Framework, an established abstraction layer in C that
enables queries and interchange of complex data - spun-out from GnuCash.
QSF is the XML file backend for QOF, newly written for this project but using
a backend framework already in use in GnuCash. You'll need the newest version
of QOF - 0.7.2 which is and available from http://qof.sourceforge.net/ . 

For support, please subscribe to the QOF-devel mailing list:
http://lists.sourceforge.net/lists/listinfo/qof-devel

For information on QOF, see:

http://qof.sourceforge.net/doxy/

http://qof.sourceforge.net/

For updated information on the latest QOF source, see:

http://code.neil.williamsleesmill.me.uk/doxygen/group__QOF.html

For information on the QOF XML backend, QSF, see:

http://code.neil.williamsleesmill.me.uk/doxygen/group__QSF.html

http://code.neil.williamsleesmill.me.uk/qsf.html

*/

==> gpe-expenses_0.1.7.orig.tar.gz: gpe-expenses-0.1.7/doc/doxygen_main_page.c <==
/* Copyright  2005  Neil Williams <linux@codehelp.co.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
/** @mainpage libqofexpensesobjects

QOF is Query Object Framework, an established abstraction layer in C that
enables queries and interchange of complex data - spun-out from GnuCash.
QSF is the XML file backend for QOF, newly written for this project but using
a backend framework already in use in GnuCash.

gpe-expenses provides an executable interface to the QOF external framework.
It supports writing the QSF XML offline storage and SQL-type queries. The
library contains the QOF objects that dictate the data structures used in
gpe-expenses.

For support, please subscribe to the QOF-devel mailing list:
http://lists.sourceforge.net/lists/listinfo/qof-devel

For information on QOF, see:

http://qof.sourceforge.net/doxy/

http://qof.sourceforge.net/

For updated information on the latest QOF source, see:

http://code.neil.williamsleesmill.me.uk/doxygen/group__QOF.html

For information on the QOF XML backend, QSF, see:

http://code.neil.williamsleesmill.me.uk/doxygen/group__QSF.html

http://code.neil.williamsleesmill.me.uk/qsf.html

*/
